@@ -1,15 +1,15 @@
 import asyncio
-import gc
 import re
-import sys
 import time
-from collections import OrderedDict, defaultdict
+from collections import OrderedDict
 from typing import Any, Optional, Tuple, Union
 
-from ..key import get_template_and_func_for
 from .interface import Backend
 
 __all__ = "Memory"
+
+from ..utils import _get_obj_size
+
 _missed = object()
 
 
@@ -148,28 +148,3 @@ class Memory(Backend):
         if key in self.store:
             return _get_obj_size(self.store[key])
         return 0
-
-
-def _get_obj_size(obj) -> int:
-    marked = {id(obj)}
-    obj_q = [obj]
-    size = 0
-
-    while obj_q:
-        size += sum(map(sys.getsizeof, obj_q))
-
-        # Lookup all the object referred to by the object in obj_q.
-        # See: https://docs.python.org/3.7/library/gc.html#gc.get_referents
-        all_refr = ((id(o), o) for o in gc.get_referents(*obj_q))
-
-        # Filter object that are already marked.
-        # Using dict notation will prevent repeated objects.
-        new_refr = {o_id: o for o_id, o in all_refr if o_id not in marked and not isinstance(o, type)}
-
-        # The new obj_q will be the ones that were not marked,
-        # and we will update marked with their ids so we will
-        # not traverse them again.
-        obj_q = new_refr.values()
-        marked.update(new_refr.keys())
-
-    return size
