@@ -1,6 +1,6 @@
 from .cache.defaults import CacheDetect, context_cache_detect  # noqa
 from .cache.early import early  # noqa
-from .cache.fail import failover  # noqa
+from .cache.fail import failover, fast_condition  # noqa
 from .cache.hit import hit  # noqa
 from .cache.simple import cache  # noqa
 from .circuit_breaker import CircuitBreakerOpen, circuit_breaker  # noqa
