@@ -35,7 +35,7 @@ def cache(
                 _from_cache._set(_cache_key, ttl=ttl, name="simple", backend=backend.name)
                 return cached
             result = await func(*args, **kwargs)
-            if store(result, args, kwargs):
+            if store(result, args, kwargs, key=_cache_key):
                 await backend.set(_cache_key, result, expire=ttl)
             return result
 
