@@ -1,24 +1,46 @@
+import asyncio
 from functools import partial, wraps
 from typing import Any, Callable, Dict, Iterable, Optional, Tuple, Type, Union
 from urllib.parse import parse_qsl, urlparse
 
 from . import decorators, validation
-from .backends.client_side import BcastClientSide
-from .backends.index import IndexRedis
 from .backends.interface import Backend
 from .backends.memory import Memory
-from .backends.redis import Redis
 from .disable_control import ControlMixin, _is_disable_middleware
 from .key import ttl_to_seconds
 from .typing import TTL, CacheCondition
 
+try:
+    import aioredis
+except ImportError:
+    BcastClientSide, IndexRedis, Redis = None, None, None
+else:
+    from .backends.client_side import BcastClientSide
+    from .backends.index import IndexRedis
+    from .backends.redis import Redis
+
+    del aioredis
+
 #  pylint: disable=too-many-public-methods
 
 
-async def _auto_init(call, *args, backend=None, cmd=None, **kwargs):
-    if not backend.is_init:
-        await backend.init()
-    return await call(*args, **kwargs)
+class BackendNotAvailable(Exception):
+    pass
+
+
+def _create_auto_init():
+    lock = asyncio.Lock()
+
+    async def _auto_init(call, *args, backend=None, cmd=None, **kwargs):
+        if backend.is_init:
+            return await call(*args, **kwargs)
+        async with lock:
+            if not backend.is_init:
+                await backend.init()
+
+        return await call(*args, **kwargs)
+
+    return _auto_init
 
 
 class Cache(Backend):
@@ -26,7 +48,7 @@ class Cache(Backend):
 
     def __init__(self, name=None):
         self._backends = {}
-        self._default_middlewares = (_is_disable_middleware, _auto_init, validation._invalidate_middleware)
+        self._default_middlewares = (_is_disable_middleware, _create_auto_init(), validation._invalidate_middleware)
         self._name = name
         self._default_fail_exceptions = Exception
 
@@ -171,10 +193,10 @@ class Cache(Backend):
             async def _call(*args, **kwargs):
                 with decorators.context_cache_detect as detect:
 
-                    def new_condition(result, _args, _kwargs):
+                    def new_condition(result, _args, _kwargs, key):
                         if detect.keys:
                             return False
-                        return condition(result, _args, _kwargs) if condition else result is not None
+                        return condition(result, _args, _kwargs, key=key) if condition else result is not None
 
                     decorator = decorator_fabric(self, **decor_kwargs, condition=new_condition)
                     result = await decorator(func)(*args, **kwargs)
@@ -393,6 +415,8 @@ def settings_url_parse(url):
     params.update(dict(parse_qsl(parse_result.query)))
     params = _fix_params_types(params)
     if parse_result.scheme == "redis":
+        if Redis is None:
+            raise BackendNotAvailable("Redis backend requires `aioredis` to be installed.")
         params["backend"] = Redis
         params["address"] = parse_result._replace(query=None)._replace(fragment=None).geturl()
     elif parse_result.scheme == "mem":
