@@ -1,20 +1,21 @@
 import asyncio
-import os
 import sys
 from unittest.mock import Mock
 
 import pytest
+
 from cashews.backends.interface import Backend, ProxyBackend
 from cashews.backends.memory import Memory
-from cashews.backends.redis import Redis
 
 pytestmark = pytest.mark.asyncio
 
 
-@pytest.fixture(name="cache")
-async def _cache():
-    if os.environ.get("USE_REDIS"):
-        redis = Redis("redis://", hash_key=None)
+@pytest.fixture(name="cache", params=["memory", pytest.param("redis", marks=pytest.mark.redis)])
+async def _cache(request, redis_dsn):
+    if request.param == "redis":
+        from cashews.backends.redis import Redis
+
+        redis = Redis(redis_dsn, hash_key=None)
         await redis.init()
         await redis.clear()
         return redis
@@ -135,8 +136,8 @@ async def test_get_size(cache: Backend):
     await cache.set("test", b"1")
     assert await cache.get_size("test") in (
         sys.getsizeof((None, b"1")) + sys.getsizeof(b"1") + sys.getsizeof(None),
-        66,
-    )  # 106 - ordered dict,  66 redis
+        68,
+    )  # 106 - ordered dict,  68 redis
 
 
 async def test_lru():
