@@ -1,14 +1,13 @@
 import asyncio
-import os
 from unittest.mock import Mock
 
 import pytest
+
 from cashews import decorators
 from cashews.backends.memory import Backend, Memory
-from cashews.backends.redis import Redis
 
 pytestmark = pytest.mark.asyncio
-REDIS_TESTS = bool(os.environ.get("USE_REDIS"))
+
 EXPIRE = 0.02
 
 
@@ -16,10 +15,12 @@ class CustomError(Exception):
     pass
 
 
-@pytest.fixture(name="backend")
-async def _backend():
-    if REDIS_TESTS:
-        redis = Redis("redis://", hash_key=None)
+@pytest.fixture(name="backend", params=["memory", pytest.param("redis", marks=pytest.mark.redis)])
+async def _backend(request, redis_dsn):
+    if request.param == "redis":
+        from cashews.backends.redis import Redis
+
+        redis = Redis(redis_dsn, hash_key=None)
         await redis.init()
         await redis.clear()
         return redis
@@ -176,7 +177,7 @@ async def test_early_cache_simple(backend):
     assert await func(b"notok") == b"notok"
 
 
-@pytest.mark.skipif(REDIS_TESTS, reason="only for mem")
+@pytest.mark.redis
 async def test_early_cache_parallel(backend):
 
     mock = Mock()
@@ -374,8 +375,6 @@ async def test_context_cache_detect_deep(backend):
 
 
 async def test_context_cache_detect_context(backend):
-    assert decorators.context_cache_detect._get() is None
-
     @decorators.cache(backend, ttl=EXPIRE, key="key1")
     async def func1():
         return 1
@@ -394,8 +393,6 @@ async def test_context_cache_detect_context(backend):
     assert await func1() == "test"
     assert await func2() == "test"
 
-    assert decorators.context_cache_detect._get() is None
-
     with decorators.context_cache_detect as detector:
         assert await asyncio.create_task(func(func1())) == 1
         assert await asyncio.create_task(func(func1(), func2())) == 2
@@ -404,5 +401,4 @@ async def test_context_cache_detect_context(backend):
 
         assert len(detector.keys) == 2
 
-    assert decorators.context_cache_detect._get() is None
     assert decorators.context_cache_detect._levels == {}
