@@ -1,30 +1,28 @@
-
 import os
 
 import pytest
-from cashews.backends.index import IndexRedis
+
 from cashews.key import register_template
 
-pytestmark = pytest.mark.asyncio
-REDIS_TESTS = bool(os.environ.get("USE_REDIS"))
+pytestmark = [pytest.mark.asyncio, pytest.mark.redis]
 
 
 @pytest.fixture(name="cache")
-async def _cache():
-    redis = IndexRedis(address="redis://", hash_key=None, index_field="user", index_name="test")
+async def _cache(redis_dsn):
+    from cashews.backends.index import IndexRedis
+
+    redis = IndexRedis(address=redis_dsn, hash_key=None, index_field="user", index_name="test")
     await redis.init()
     await redis.clear()
     return redis
 
 
-@pytest.mark.skipif(not REDIS_TESTS, reason="only for redis")
 async def test_set(cache):
     register_template(test_set, "key:{user}:{account}")
     await cache.set("key:jon:10", b"val")
     assert await cache.hget("test:jon", "key:10") == b"val"
 
 
-@pytest.mark.skipif(not REDIS_TESTS, reason="only for redis")
 async def test_get(cache):
     register_template(test_get, "key:{user}:{account}")
     await cache.hset("test:jon", "key:10", b"val")
@@ -32,13 +30,11 @@ async def test_get(cache):
     assert await cache.get("key:jon:10") == b"val"
 
 
-@pytest.mark.skipif(not REDIS_TESTS, reason="only for redis")
 async def test_get_set_no_template(cache):
     await cache.set("1:jon:10", b"val")
     assert await cache.get("1:jon:10") == b"val"
 
 
-@pytest.mark.skipif(not REDIS_TESTS, reason="only for redis")
 async def test_delete_match(cache):
     register_template(test_get, "key:{user}:{account}")
     await cache.hset("test:jon", "key:10", b"val")
@@ -47,7 +43,6 @@ async def test_delete_match(cache):
     assert await cache.get("key:jon:10") is None
 
 
-@pytest.mark.skipif(not REDIS_TESTS, reason="only for redis")
 async def test_delete(cache):
     register_template(test_get, "key:{user}:{account}")
     await cache.hset("test:jon", "key:10", b"val")
